window.Gleam.initSearch([{"doc":"gleamql","title":"gleamql","content":"# gleamql\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamql)](https://hex.pm/packages/gleamql)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamql/)\n\nA Simple Graphql Client Written In Gleam ✨\n\n## Usage\n\n```gleam\nimport gleamql\nimport gleam/json.{string}\nimport gleam/dynamic.{field}\nimport gleam/option.{Some}\nimport gleam/hackney\n\npub type Data {\n  Data(country: Country)\n}\n\npub type Country {\n  Country(name: String)\n}\n\nconst country_query = &quot;query CountryQuery($code: ID!) {\n  country(code: $code) {\n    name\n  }\n}&quot;\n\npub fn main() {\n  assert Ok(Some(Data(country: Country(name: &quot;United Kingdom&quot;)))) =\n    gleamql.new()\n    |&gt; gleamql.set_query(country_query)\n    |&gt; gleamql.set_variable(&quot;code&quot;, json.string(&quot;GB&quot;))\n    |&gt; gleamql.set_host(&quot;countries.trevorblades.com&quot;)\n    |&gt; gleamql.set_path(&quot;/graphql&quot;)\n    |&gt; gleamql.set_header(&quot;Content-Type&quot;, &quot;application/json&quot;)\n    |&gt; gleamql.decode(dynamic.decode1(\n      Data,\n      field(\n        &quot;country&quot;,\n        of: fn(country) {\n          country\n          |&gt; dynamic.decode1(Country, field(&quot;name&quot;, of: string))\n        },\n      ),\n    ))\n    |&gt; gleamql.send(hackney.send)\n}\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add gleamql\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/gleamql&gt;.\n","url":"index.html"},{"doc":"gleamql","title":"GraphQLError","content":"pub type GraphQLError {\n  ErrorMessage(message: String)\n  UnexpectedStatus(status: Int)\n  UnrecognisedResponse(response: String)\n  UnknownError(inner: Dynamic)\n}\n\nErrorMessage(message: String)\n\n\nUnexpectedStatus(status: Int)\n\n\nUnrecognisedResponse(response: String)\n\n\nUnknownError(inner: Dynamic)\n\n\nSynonyms:\ngleamql.GraphQLError\ngleamql GraphQLError","url":"gleamql.html#GraphQLError"},{"doc":"gleamql","title":"Request","content":"pub type Request(t) {\n  Request(\n    http_request: request.Request(String),\n    query: Option(String),\n    variables: Option(List(#(String, Json))),\n    decoder: Option(Decoder(t)),\n  )\n}\n\nRequest(\n  http_request: request.Request(String),\n  query: Option(String),\n  variables: Option(List(#(String, Json))),\n  decoder: Option(Decoder(t)),\n)\n\n\nSynonyms:\ngleamql.Request\ngleamql Request","url":"gleamql.html#Request"},{"doc":"gleamql","title":"decode","content":"pub fn decode(req: Request(a), decoder: fn(Dynamic) -&gt;\n    Result(a, List(DecodeError))) -&gt; Request(a)\n\nSynonyms:\ngleamql.decode\ngleamql decode","url":"gleamql.html#decode"},{"doc":"gleamql","title":"new","content":"pub fn new() -&gt; Request(a)\n\nSynonyms:\ngleamql.new\ngleamql new","url":"gleamql.html#new"},{"doc":"gleamql","title":"send","content":"pub fn send(req: Request(a), send: fn(\n    gleam/http/request.Request(String),\n  ) -&gt; Result(Response(String), b)) -&gt; Result(\n  Option(a),\n  GraphQLError,\n)\n\nSynonyms:\ngleamql.send\ngleamql send","url":"gleamql.html#send"},{"doc":"gleamql","title":"set_header","content":"pub fn set_header(req: Request(a), key: String, value: String) -&gt; Request(\n  a,\n)\n\nSynonyms:\ngleamql.set_header\ngleamql set_header","url":"gleamql.html#set_header"},{"doc":"gleamql","title":"set_host","content":"pub fn set_host(req: Request(a), host: String) -&gt; Request(a)\n\nSynonyms:\ngleamql.set_host\ngleamql set_host","url":"gleamql.html#set_host"},{"doc":"gleamql","title":"set_path","content":"pub fn set_path(req: Request(a), path: String) -&gt; Request(a)\n\nSynonyms:\ngleamql.set_path\ngleamql set_path","url":"gleamql.html#set_path"},{"doc":"gleamql","title":"set_query","content":"pub fn set_query(req: Request(a), query: String) -&gt; Request(a)\n\nSynonyms:\ngleamql.set_query\ngleamql set_query","url":"gleamql.html#set_query"},{"doc":"gleamql","title":"set_variable","content":"pub fn set_variable(req: Request(a), key: String, value: Json) -&gt; Request(\n  a,\n)\n\nSynonyms:\ngleamql.set_variable\ngleamql set_variable","url":"gleamql.html#set_variable"},{"doc":"gleamql","title":"gleamql","content":"","url":"gleamql.html"}]);